from setuptools import setup

setup(name='mylibfahad',
      version='0.2',
      description='Testing to creat a library',
      url='http://dont-have-link.com/no-link',
      author='fahad.shawal',
      author_email='fahadshawal@gmail.com',
      license='MIT',
      packages=['mylib'],
      zip_safe=False)
